@@ -9,7 +9,7 @@ use feature ":5.10";
 use Config;
 use File::Spec::Functions qw(catdir rel2abs splitpath);
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use constant DFLT_TOCOPY_SECTION  => "__TOCOPY__";
 
@@ -283,7 +283,8 @@ sub parse_ini {
     {$tocopy_section => ($self->{+TOCOPY_VARS} ? {%{$self->{+TOCOPY_VARS}}} : {})};
 
   my $global_vars = $self->{+GLOBAL_VARS} = {%Globals};
-  my $tocopy_sec_vars = $self->{+VARIABLES}{$tocopy_section};
+  my $variables = $self->{+VARIABLES};
+  my $tocopy_sec_vars = $variables->{$tocopy_section};
   if (my $ref_src = ref($src)) {
     $self->{+SRC_NAME} = $dflt_src_name if !exists($self->{+SRC_NAME});
     if ($ref_src eq 'ARRAY') {
@@ -318,29 +319,32 @@ sub parse_ini {
 
   my ($tocopy_sec_declared, undef) = $self->$_parse_ini($src);
 
-  while (my ($section, $variables) = each(%{$self->{+VARIABLES}})) {
-    while (my ($variable, $value) = each(%$variables)) {
-      $variables->{$variable} = $self->$_expand_vars($section, $variable, $value);
+  my @sections = (exists($self->{+SECTIONS_H}{$tocopy_section}) ? () : $tocopy_section,
+                  @{$self->{+SECTIONS}}
+                 );
+  foreach my $section (@sections) {
+    my $sec_vars = $variables->{$section};
+    while (my ($variable, $value) = each(%$sec_vars)) {
+      $sec_vars->{$variable} = $self->$_expand_vars($section, $variable, $value);
     }
   }
   if ($cleanup) {
-    while (my ($section, $variables) = each(%{$self->{+VARIABLES}})) {
-      foreach my $var (keys(%$variables)) {
-        delete $variables->{$var} if index($var, '=') >= 0;
+    while (my ($section, $sec_vars) = each(%{$variables})) {
+      foreach my $var (keys(%$sec_vars)) {
+        delete $sec_vars->{$var} if index($var, '=') >= 0;
       }
     }
-    delete $self->{+VARIABLES}{$self->{+TOCOPY_SECTION}} if (!$tocopy_sec_declared &&
-                                                             !%$tocopy_sec_vars);
+    delete $variables->{$self->{+TOCOPY_SECTION}} if (!$tocopy_sec_declared && !%$tocopy_sec_vars);
   }
   else {
     if ($self->{+GLOBAL_MODE}) {
-      while (my ($section, $sec_vars) = each(%{$self->{+VARIABLES}})) {
+      while (my ($section, $sec_vars) = each(%{$variables})) {
         $sec_vars->{'='} = $section;
       }
       @{$tocopy_sec_vars}{keys(%$global_vars)} = values(%$global_vars);
     }
     else {
-      while (my ($section, $sec_vars) = each(%{$self->{+VARIABLES}})) {
+      while (my ($section, $sec_vars) = each(%{$variables})) {
         $sec_vars->{'='} = $section;
         @{$sec_vars}{keys(%$global_vars)} = values(%$global_vars);
       }
@@ -388,6 +392,9 @@ $_look_up = sub {
   elsif ($v_basename =~ /^=(?:ENV|env):\s*(.*)$/) {
     $v_value = $ENV{$1} // "";
   }
+  elsif ($v_basename =~ /^=CONFIG:\s*(.*)$/) {
+    $v_value = $Config{$1} // "";
+  }
   elsif (exists($self->{+GLOBAL_VARS}{$v_basename})) {
     $v_value = $self->{+GLOBAL_VARS}{$v_basename};
   }
@@ -428,7 +435,7 @@ $_expand_vars = sub {
   if (defined($variable)) {
     ((my $var_basename), $x_variable_name) = $self->$_x_var_name($curr_sect, $variable);
     return $self->$_look_up($curr_sect, $variable) if (exists($self->{+EXPANDED}{$x_variable_name})
-                                                       || $var_basename =~ /^=ENV:/);
+                                                       || $var_basename =~ /^=(?:ENV|CONFIG):/);
     croak("recursive variable '", $x_variable_name, "' references itself")
       if exists($seen->{$x_variable_name});
     $seen->{$x_variable_name} = undef if !$not_seen;
@@ -492,7 +499,7 @@ Config::INI::RefVars - INI file reader, allows the referencing of INI and enviro
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =head1 SYNOPSIS
 
@@ -507,25 +514,32 @@ Version 0.10
 
 If the INI file contains:
 
+   section = $(=)
+
    [sec A]
-   foo=this value
-   bar=that value
+   foo=Variable $(==) in section $(section)
+   bar:=$(foo)
+   foo.=!
 
    [sec B]
-   baz = yet another value
+   baz = from $(=): ref foo from sec A: $([sec A]foo)
 
 then C<< $ini_reader->variables >> returns:
 
-   {
-       'sec A' => {
-                    'bar' => 'that value',
-                    'foo' => 'this value'
-                  },
-       'sec B' => {
-                    'baz' => 'yet another value'
-                  }
-   }
-
+  {
+    '__TOCOPY__' => {
+                      'section' => '__TOCOPY__'
+                    },
+    'sec A' => {
+                 'bar' => 'Variable foo in section sec A',
+                 'foo' => 'Variable foo in section sec A!',
+                 'section' => 'sec A'
+               },
+    'sec B' => {
+                 'baz' => 'from sec B: ref foo from sec A: Variable foo in section sec A!',
+                 'section' => 'sec B'
+               }
+  }
 
 =head1 DESCRIPTION
 
@@ -934,7 +948,7 @@ argument C<cleanup>. The variable C<==> can of course not be included in the
 result.
 
 
-=head2 ACCESSING ENVIRONMENT VARIABLES
+=head2 ACCESSING ENVIRONMENT AND CONFIG VARIABLES
 
 You can access environment variables with this C<$(=ENV:...)> or this
 C<$(=env:...)> notation. Example:
@@ -955,6 +969,15 @@ value C<$(var)> and you write this in your INI file:
 
 This results in C<x> having the value C<$(var)>, while C<y> has the value C<hello!>.
 
+You can access configuration variables of Perl's L<Config> module with this C<$(=:CONFIG...)> notation. Example:
+
+  the archlib=$(=CONFIG:archlib)
+
+This gives the variable C<the archlib> the value of C<$Config{archlib}>.
+
+Note: In contrast to C<=ENV:...>, there is no lower-case counterpart to
+C<$(=CONFIG:...)>, as this would not make sense.
+
 
 =head2 THE SECTION I<TOCOPY>
 
@@ -1027,7 +1050,9 @@ the variables of the I<tocopy> section are not copied, but behave like global
 variables. Variables that you specify with the argument C<not_tocopy> are not
 treated as global.
 
-As a result, there is no difference in referencing variables if you use globale mode. The benefit of this mode is that you do not mess up your sections with unwanted variables.
+Consequently, there is almost no difference in the referencing of variables if
+you use the global mode. The advantage of this mode is that you do not clutter
+your sections with unwanted variables.
 
 Example:
 
@@ -1052,6 +1077,44 @@ But in global mode the result is:
      sec        => {x => 'y'}
    }
 
+For a local copy of a global variable, use assignment operator C<:=>.
+
+A difference occurs if you you use C<$(=)> in a global variable:
+
+   section=$(=)
+
+   [sec A]
+   var 1 = $(section)
+   var 2 := $(section)
+
+In global mode, you will get this:
+
+   {
+     '__TOCOPY__' => {
+                       'section' => '__TOCOPY__'
+                     },
+     'sec A' => {
+                  'var 1' => '__TOCOPY__',
+                  'var 2' => 'sec A'
+                }
+   }
+
+But without global mode you will get:
+
+   {
+     '__TOCOPY__' => {
+                       'section' => '__TOCOPY__'
+                     },
+     'sec A' => {
+                  'section' => 'sec A',
+                  'var 1' => 'sec A',
+                  'var 2' => 'sec A'
+                }
+   }
+
+Note the difference in the value of C<var 1>!
+
+
 =head2 COMMENTS
 
 As said, if the first non-white character of a line is a C<;> or a C<#>, then the line
